# QtMPLtools
QtMPLtools is a package that integrates a set of custom Matplotlib plugins for the python GUI editor Qt designer, aiming to be able to drag and drop plot widgets on a GUI form. This package is based on the PyQt6 library (as opposed to PySide6).

## Launching designer

Type the following to launch QT designer with the Matplotlib plugins included:

```python
designer
```

## Checking if there was a successful installation
Once designer is launched, you should see 4 types of matplotlib plots under a 'Plots' group:

<img width="300" alt="mpltools_designer" src="https://github.com/dresis/QtMPLtools/assets/147135495/0be78bf1-dc0e-442d-a7d8-8cdf48ad1779">
